package com.huimv.management.limit.annotation;

import com.huimv.management.limit.enums.LimitType;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * <p>
 * 业务用注解
 * </p>
 * 示例: @Limit(key = "test_list",name = "test/list",prefix = "management")
 * @author huimv
 * @since 2021/4/29
 */
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Limit {

    /**
     * 资源名称，用于描述接口功能
     */
    String name() default "";

    /**
     * 资源 key
     */
    String key() default "";

    /**
     * key prefix
     */
    String prefix() default "";

    /**
     * 时间范围，单位秒
     */
    long period() default 60 * 60 * 24L;

    /**
     * 限制访问次数
     */
    long count() default 3L;

    /**
     * 限制类型
     */
    LimitType limitType() default LimitType.IP;
}
